from setuptools import setup  # type: ignore

setup(
    name="ezaws",
    version="0.12",
    packages=["ezaws"],
    description="An easy to use interface to AWS, ezaws.",
    url="https://github.com/saidvandeklundert/ezaws",
    classifiers=["Programming Language :: Python :: 3"],
    python_requires=">=3.10, <4",
    project_urls={
        "Bug Reports": "https://github.com/saidvandeklundert/ezaws/issues",
        "Source": "https://github.com/saidvandeklundert/ezaws",
        "Documentation": "https://github.com/saidvandeklundert/ezaws",
    },
)
